@@ -272,8 +272,14 @@ trajectory.analysis <- function(fit, fit.null = NULL, groups,
   }) else NULL
   
   if(is.null(Tcor)) {
-    cat("\nWarning: Univariate response variable detected...")
-    cat("\nTrajectory correlation analyses not possible.")
+    
+    warning(
+      paste(
+        "\nUnivariate response variable detected...",
+        "\nTrajectory correlation analyses not possible.\n",
+        sep = " "),
+      noBreaks. = TRUE, call. = FALSE, immediate. = TRUE) 
+    
   }
   
   # Pairwise shape differences
